#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hasql
version:              1.5.0.5
visibility:           public
id:                   hasql-1.5.0.5-kN1cqZ2zOOEjrK89myZtq
key:                  hasql-1.5.0.5-kN1cqZ2zOOEjrK89myZtq
license:              MIT
copyright:            (c) 2014, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/hasql
synopsis:             An efficient PostgreSQL driver with a flexible mapping API
description:
    Root of the \"hasql\" ecosystem.
    For details and tutorials see
    <https://github.com/nikita-volkov/hasql the readme>.

    The API comes free from all kinds of exceptions. All error-reporting is explicit and is presented using the '\''Either'\'' type.

category:             Hasql, Database, PostgreSQL
abi:                  861c68d89a275d0affc10a59c0da9594
exposed:              True
exposed-modules:
    Hasql.Connection Hasql.Decoders Hasql.Encoders Hasql.Session
    Hasql.Statement

hidden-modules:
    Hasql.Private.Prelude Hasql.Private.Errors Hasql.Private.PTI
    Hasql.Private.IO Hasql.Private.Session Hasql.Private.Connection
    Hasql.Private.PreparedStatementRegistry Hasql.Private.Settings
    Hasql.Private.Commands Hasql.Private.Decoders
    Hasql.Private.Decoders.Array Hasql.Private.Decoders.Composite
    Hasql.Private.Decoders.Value Hasql.Private.Decoders.Row
    Hasql.Private.Decoders.Result Hasql.Private.Decoders.Results
    Hasql.Private.Encoders Hasql.Private.Encoders.Array
    Hasql.Private.Encoders.Value Hasql.Private.Encoders.Params

import-dirs:          /usr/lib/ghc-9.6.6/site-local/hasql-1.5.0.5
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hasql-1.5.0.5
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hasql-1.5.0.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hasql
hs-libraries:         HShasql-1.5.0.5-kN1cqZ2zOOEjrK89myZtq
depends:
    attoparsec-0.14.4-LPUfgM6EYDdB1TDDplKPaC base-4.18.2.1
    bytestring-0.11.5.3
    bytestring-strict-builder-0.4.5.8-CGzjrKfgeyIMoyluaspt1
    contravariant-1.5.5-JUOgBPNZkO18h7ix7HMuaW
    dlist-1.0-B7D1vsARFiIHVaGk5CGbYO
    hashable-1.4.7.0-DcMaISCS2qf3eQMEkeWh0S
    hashtables-1.4.2-53PAnDGmZ1YKRutmx1Bupy mtl-2.3.1
    postgresql-binary-0.12.5-7RQGiLgIvkmIV0RqUTjexJ
    postgresql-libpq-0.9.5.0-6Abcvnlrbx38D8lE6uFyjU
    profunctors-5.6.3-HiKvJc09ytI5Ao2Cu2uXjR text-2.0.2
    text-builder-0.6.7-1fpoqgTa7GUA0z11UxfbE0 transformers-0.6.1.0
    vector-0.13.2.0-AKpLem9JWa2IilUORfhwQi

haddock-interfaces:   /usr/share/doc/haskell-hasql/html/hasql.haddock
haddock-html:         /usr/share/doc/haskell-hasql/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

